@@ -1,10 +1,10 @@
 from io import BytesIO
+import urllib
 
 from flask import request
 from flask.views import MethodView
 from pygments.lexers import get_all_lexers
 from werkzeug.exceptions import Forbidden
-from werkzeug.urls import url_quote
 
 from ..constants import FOREVER
 from ..utils.http import redirect_next
@@ -53,4 +53,4 @@ class LodgeitUpload(MethodView):
         maxlife_timestamp = FOREVER
         name = create_item(f, filename, size, content_type, content_type_hint,
                            maxlife_stamp=maxlife_timestamp)
-        return redirect_next('bepasty.display', name=name, _anchor=url_quote(filename))
+        return redirect_next('bepasty.display', name=name, _anchor=urllib.parse.quote(filename))
