@@ -1,5 +1,6 @@
 FILENAME = 'filename'
 TYPE = 'type'
+TYPE_HINT = 'type-hint'
 LOCKED = 'locked'
 SIZE = 'size'
 COMPLETE = 'complete'
@@ -9,3 +10,9 @@ TIMESTAMP_DOWNLOAD = 'timestamp-download'
 TIMESTAMP_MAX_LIFE = 'timestamp-max-life'
 ID = 'id'  # storage name
 FOREVER = -1
+
+# headers
+TRANSACTION_ID = 'Transaction-ID'  # keep in sync with bepasty-cli
+
+# used internally only
+internal_meta = [TYPE_HINT]
