@@ -30,7 +30,7 @@ class DeleteView(MethodView):
 
             current_app.storage.remove(name)
 
-        except (OSError, IOError) as e:
+        except OSError as e:
             if e.errno == errno.ENOENT:
                 raise NotFound()
             raise
